<?php
/**
 * URL Coupons for WooCommerce - General Section Settings
 *
 * @version 1.0.0
 * @since   1.0.0
 * @author  Algoritmika Ltd.
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_URL_Coupons_Settings_General' ) ) :

class Alg_WC_URL_Coupons_Settings_General extends Alg_WC_URL_Coupons_Settings_Section {

	/**
	 * Constructor.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function __construct() {
		$this->id   = '';
		$this->desc = __( 'General', 'url-coupons-woocommerce' );
		parent::__construct();
	}

	/**
	 * add_settings.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function add_settings( $settings ) {
		$main_settings = array(
			array(
				'title'    => __( 'URL Coupons Options', 'url-coupons-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_url_coupons_options',
			),
			array(
				'title'    => __( 'URL Coupons for WooCommerce', 'url-coupons-woocommerce' ),
				'desc'     => '<strong>' . __( 'Enable plugin', 'url-coupons-woocommerce' ) . '</strong>',
				'id'       => 'alg_wc_url_coupons_enabled',
				'default'  => 'yes',
				'type'     => 'checkbox',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_url_coupons_options',
			),
		);
		$general_settings = array(
			array(
				'title'    => __( 'Options', 'url-coupons-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_url_coupons_general_options',
			),
			array(
				'title'    => __( 'URL Coupons Key', 'url-coupons-woocommerce' ),
				'desc_tip' => __( 'URL key. If you change this, make sure it\'s unique and is not used anywhere on your site (e.g. by another plugin).', 'url-coupons-woocommerce' ),
				'desc'     => sprintf( __( 'Your users can apply shop\'s standard coupons, by visiting URL. E.g.: %s.', 'url-coupons-woocommerce' ),
					'<code>' . site_url() . '/?' . get_option( 'alg_wc_url_coupons_key', 'alg_apply_coupon' ) . '=couponcode' . '</code>' ),
				'id'       => 'alg_wc_url_coupons_key',
				'default'  => 'alg_apply_coupon',
				'type'     => 'text',
			),
			array(
				'title'    => __( 'Redirect URL', 'url-coupons-woocommerce' ),
				'desc_tip' => __( 'Possible values: No redirect; redirect to cart; redirect to checkout; redirect to custom local URL.', 'url-coupons-woocommerce' ),
				'id'       => 'alg_wc_url_coupons_redirect',
				'default'  => 'no',
				'type'     => 'select',
				'options'  => array(
					'no'       => __( 'No redirect', 'url-coupons-woocommerce' ),
					'cart'     => __( 'Redirect to cart', 'url-coupons-woocommerce' ),
					'checkout' => __( 'Redirect to checkout', 'url-coupons-woocommerce' ),
					'custom'   => __( 'Redirect to custom local URL', 'url-coupons-woocommerce' ),
				),
				'desc'     => apply_filters( 'alg_wc_url_coupons', sprintf( __( 'This option is only available in <a href="%s" target="_blank">URL Coupons for WooCommerce Pro</a> plugin version.', 'url-coupons-woocommerce' ), 'https://wpcodefactory.com/item/url-coupons-woocommerce/' ), 'settings' ),
				'custom_attributes' => apply_filters( 'alg_wc_url_coupons', array( 'disabled' => 'disabled' ), 'settings' ),
			),
			array(
				'desc'     => __( 'Custom Local URL', 'url-coupons-woocommerce' ),
				'id'       => 'alg_wc_url_coupons_redirect_custom_url',
				'default'  => '',
				'type'     => 'text',
				'css'      => 'min-width:300px;',
			),
			array(
				'title'    => __( '"Fixed product discount" Coupons', 'url-coupons-woocommerce' ),
				'desc'     => __( 'Automatically add coupon\'s products to the cart', 'url-coupons-woocommerce' ),
				'id'       => 'alg_wc_url_coupons_fixed_product_discount_add_products',
				'default'  => 'no',
				'type'     => 'checkbox',
				'desc_tip' => apply_filters( 'alg_wc_url_coupons', sprintf( __( 'This option is only available in <a href="%s" target="_blank">URL Coupons for WooCommerce Pro</a> plugin version.', 'url-coupons-woocommerce' ), 'https://wpcodefactory.com/item/url-coupons-woocommerce/' ), 'settings' ),
				'custom_attributes' => apply_filters( 'alg_wc_url_coupons', array( 'disabled' => 'disabled' ), 'settings' ),
			),
			array(
				'title'    => __( 'Hide Coupon on Cart Page', 'url-coupons-woocommerce' ),
				'desc'     => __( 'Hide', 'url-coupons-woocommerce' ),
				'desc_tip' => __( 'Enable this if you want to hide standard coupon field on cart page.', 'url-coupons-woocommerce' ),
				'id'       => 'alg_wc_url_coupons_cart_hide_coupon',
				'default'  => 'no',
				'type'     => 'checkbox',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_url_coupons_general_options',
			),
		);
		return array_merge( $main_settings, $general_settings, $settings );
	}

}

endif;

return new Alg_WC_URL_Coupons_Settings_General();
