<?php
/**
 * URL Coupons for WooCommerce - Core Class
 *
 * @version 1.0.0
 * @since   1.0.0
 * @author  Algoritmika Ltd.
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_URL_Coupons_Core' ) ) :

class Alg_WC_URL_Coupons_Core {

	/**
	 * Constructor.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 * @todo    (maybe) "hide coupon" - maybe it's safer to hide coupons with CSS instead of using filter
	 */
	function __construct() {
		if ( 'yes' === get_option( 'alg_wc_url_coupons_enabled', 'yes' ) ) {
			add_action( 'wp_loaded', array( $this, 'maybe_apply_url_coupon' ), PHP_INT_MAX );
			// Hide coupon
			if ( 'yes' === get_option( 'alg_wc_url_coupons_cart_hide_coupon', 'no' ) ) {
				add_filter( 'woocommerce_coupons_enabled', array( $this, 'hide_coupon_field_on_cart' ), PHP_INT_MAX );
			}
		}
	}

	/**
	 * hide_coupon_field_on_cart.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function hide_coupon_field_on_cart( $enabled ) {
		return ( is_cart() ) ? false : $enabled;
	}

	/**
	 * is_product_in_cart.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function is_product_in_cart( $product_id ) {
		if ( 0 != $product_id ) {
			if ( isset( WC()->cart->cart_contents ) && is_array( WC()->cart->cart_contents ) ) {
				foreach ( WC()->cart->cart_contents as $cart_item_key => $cart_item_data ) {
					if (
						( isset( $cart_item_data['product_id'] )   && $product_id == $cart_item_data['product_id'] ) ||
						( isset( $cart_item_data['variation_id'] ) && $product_id == $cart_item_data['variation_id'] )
					) {
						return true;
					}
				}
			}
		}
		return false;
	}

	/**
	 * get_redirect_url.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function get_redirect_url( $arg_key ) {
		switch ( apply_filters( 'alg_wc_url_coupons', 'no', 'value_redirect' ) ) {
			case 'cart':
				return wc_get_cart_url();
			case 'checkout':
				return wc_get_checkout_url();
			case 'custom':
				return get_option( 'alg_wc_url_coupons_redirect_custom_url', '' );
			default: // 'no'
				return remove_query_arg( $arg_key );
		}
	}

	/**
	 * maybe_add_products_to_cart.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 * @todo    (maybe) check if coupon is valid
	 */
	function maybe_add_products_to_cart( $coupon_code ) {
		if ( 'no' === apply_filters( 'alg_wc_url_coupons', 'no', 'value_fixed_product_discount_add_products' ) ) {
			return false;
		}
		// Coupons are globally disabled.
		if ( ! wc_coupons_enabled() ) {
			return false;
		}
		// Sanitize coupon code.
		$coupon_code = wc_format_coupon_code( $coupon_code );
		// Get the coupon.
		$the_coupon = new WC_Coupon( $coupon_code );
		if ( 'fixed_product' === $the_coupon->get_discount_type() ) {
			$product_ids = $the_coupon->get_product_ids();
			if ( ! empty( $product_ids ) ) {
				foreach ( $product_ids as $product_id ) {
					if ( ! $this->is_product_in_cart( $product_id ) ) {
						WC()->cart->add_to_cart( $product_id );
					}
				}
			}
		}
	}

	/**
	 * maybe_apply_url_coupon.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 * @todo    (maybe) options to add products to cart with query arg
	 * @todo    (maybe) if ( ! WC()->cart->has_discount( $coupon_code ) ) {}
	 */
	function maybe_apply_url_coupon() {
		$arg_key = get_option( 'alg_wc_url_coupons_key', 'alg_apply_coupon' );
		if ( isset( $_GET[ $arg_key ] ) && '' != $_GET[ $arg_key ] ) {
			$coupon_code = sanitize_text_field( $_GET[ $arg_key ] );
			$this->maybe_add_products_to_cart( $coupon_code );
			WC()->cart->add_discount( $coupon_code );
			wp_safe_redirect( $this->get_redirect_url( $arg_key ) );
			exit;
		}
	}

}

endif;

return new Alg_WC_URL_Coupons_Core();
